@@ -6,24 +6,6 @@ impl QueryBuilder for PostgresQueryBuilder {
         ("$", true)
     }
 
-    fn prepare_returning(
-        &self,
-        returning: &[SelectExpr],
-        sql: &mut SqlWriter,
-        collector: &mut dyn FnMut(Value),
-    ) {
-        if !returning.is_empty() {
-            write!(sql, " RETURNING ").unwrap();
-            returning.iter().fold(true, |first, expr| {
-                if !first {
-                    write!(sql, ", ").unwrap()
-                }
-                self.prepare_select_expr(expr, sql, collector);
-                false
-            });
-        }
-    }
-
     fn if_null_function(&self) -> &str {
         "COALESCE"
     }
@@ -77,4 +59,44 @@ impl QueryBuilder for PostgresQueryBuilder {
             _ => self.prepare_function_common(function, sql, collector),
         }
     }
+
+    fn prepare_simple_expr(
+        &self,
+        simple_expr: &SimpleExpr,
+        sql: &mut SqlWriter,
+        collector: &mut dyn FnMut(Value),
+    ) {
+        match simple_expr {
+            SimpleExpr::AsEnum(type_name, expr) => {
+                let simple_expr = expr.clone().cast_as(SeaRc::clone(type_name));
+                self.prepare_simple_expr_common(&simple_expr, sql, collector);
+            }
+            _ => QueryBuilder::prepare_simple_expr_common(self, simple_expr, sql, collector),
+        }
+    }
+
+    fn prepare_order_expr(
+        &self,
+        order_expr: &OrderExpr,
+        sql: &mut SqlWriter,
+        collector: &mut dyn FnMut(Value),
+    ) {
+        self.prepare_simple_expr(&order_expr.expr, sql, collector);
+        write!(sql, " ").unwrap();
+        self.prepare_order(&order_expr.order, sql, collector);
+        match order_expr.nulls {
+            None => (),
+            Some(NullOrdering::Last) => write!(sql, " NULLS LAST").unwrap(),
+            Some(NullOrdering::First) => write!(sql, " NULLS FIRST").unwrap(),
+        }
+    }
+
+    fn prepare_query_statement(
+        &self,
+        query: &SubQueryStatement,
+        sql: &mut SqlWriter,
+        collector: &mut dyn FnMut(Value),
+    ) {
+        query.prepare_statement(self, sql, collector);
+    }
 }
