@@ -14,7 +14,7 @@ pub trait QueryBuilder: QuotedBuilder {
         sql: &mut SqlWriter,
         collector: &mut dyn FnMut(Value),
     ) {
-        write!(sql, "INSERT").unwrap();
+        self.prepare_insert(insert.replace, sql);
 
         if let Some(table) = &insert.table {
             write!(sql, " INTO ").unwrap();
@@ -22,43 +22,39 @@ pub trait QueryBuilder: QuotedBuilder {
             write!(sql, " ").unwrap();
         }
 
-        if insert.columns.is_empty() && insert.source.is_none() {
-            write!(sql, "{}", self.insert_default_keyword()).unwrap();
-        } else {
-            write!(sql, "(").unwrap();
-            insert.columns.iter().fold(true, |first, col| {
-                if !first {
-                    write!(sql, ", ").unwrap()
-                }
-                col.prepare(sql, self.quote());
-                false
-            });
-            write!(sql, ")").unwrap();
+        write!(sql, "(").unwrap();
+        insert.columns.iter().fold(true, |first, col| {
+            if !first {
+                write!(sql, ", ").unwrap()
+            }
+            col.prepare(sql, self.quote());
+            false
+        });
+        write!(sql, ")").unwrap();
 
-            if let Some(source) = &insert.source {
-                write!(sql, " ").unwrap();
-                match source {
-                    InsertValueSource::Values(values) => {
-                        write!(sql, "VALUES ").unwrap();
-                        values.iter().fold(true, |first, row| {
+        if let Some(source) = &insert.source {
+            write!(sql, " ").unwrap();
+            match source {
+                InsertValueSource::Values(values) => {
+                    write!(sql, "VALUES ").unwrap();
+                    values.iter().fold(true, |first, row| {
+                        if !first {
+                            write!(sql, ", ").unwrap()
+                        }
+                        write!(sql, "(").unwrap();
+                        row.iter().fold(true, |first, col| {
                             if !first {
                                 write!(sql, ", ").unwrap()
                             }
-                            write!(sql, "(").unwrap();
-                            row.iter().fold(true, |first, col| {
-                                if !first {
-                                    write!(sql, ", ").unwrap()
-                                }
-                                self.prepare_simple_expr(col, sql, collector);
-                                false
-                            });
-                            write!(sql, ")").unwrap();
+                            self.prepare_simple_expr(col, sql, collector);
                             false
                         });
-                    }
-                    InsertValueSource::Select(select_query) => {
-                        self.prepare_select_statement(select_query.deref(), sql, collector);
-                    }
+                        write!(sql, ")").unwrap();
+                        false
+                    });
+                }
+                InsertValueSource::Select(select_query) => {
+                    self.prepare_select_statement(select_query.deref(), sql, collector);
                 }
             }
         }
@@ -89,9 +85,15 @@ pub trait QueryBuilder: QuotedBuilder {
             false
         });
 
-        if let Some(from) = &select.from {
+        if !select.from.is_empty() {
             write!(sql, " FROM ").unwrap();
-            self.prepare_table_ref(from, sql, collector);
+            select.from.iter().fold(true, |first, table_ref| {
+                if !first {
+                    write!(sql, ", ").unwrap()
+                }
+                self.prepare_table_ref(table_ref, sql, collector);
+                false
+            });
         }
 
         if !select.join.is_empty() {
@@ -806,6 +808,14 @@ pub trait QueryBuilder: QuotedBuilder {
         }
     }
 
+    fn prepare_insert(&self, replace: bool, sql: &mut SqlWriter) {
+        if replace {
+            write!(sql, "REPLACE").unwrap();
+        } else {
+            write!(sql, "INSERT").unwrap();
+        }
+    }
+
     fn prepare_function(
         &self,
         function: &Function,
@@ -1168,11 +1178,6 @@ pub trait QueryBuilder: QuotedBuilder {
     fn char_length_function(&self) -> &str {
         "CHAR_LENGTH"
     }
-
-    /// The keywords for insert default statement (insert without explicit values)
-    fn insert_default_keyword(&self) -> &str {
-        "DEFAULT VALUES"
-    }
 }
 
 impl SubQueryStatement {
