@@ -9,8 +9,8 @@ pub trait TableBuilder: IndexBuilder + ForeignKeyBuilder + QuotedBuilder {
             write!(sql, "IF NOT EXISTS ").unwrap();
         }
 
-        if let Some(table) = &create.table {
-            table.prepare(sql, self.quote());
+        if let Some(table_ref) = &create.table {
+            self.prepare_table_ref(table_ref, sql);
         }
 
         write!(sql, " ( ").unwrap();
@@ -48,6 +48,32 @@ pub trait TableBuilder: IndexBuilder + ForeignKeyBuilder + QuotedBuilder {
         }
     }
 
+    /// Translate [`TableRef`] into SQL statement.
+    fn prepare_table_ref(&self, table_ref: &TableRef, sql: &mut SqlWriter) {
+        self.prepare_table_ref_common(table_ref, sql);
+    }
+
+    fn prepare_table_ref_common(&self, table_ref: &TableRef, sql: &mut SqlWriter) {
+        match table_ref {
+            TableRef::Table(table) => {
+                table.prepare(sql, self.quote());
+            }
+            TableRef::SchemaTable(schema, table) => {
+                schema.prepare(sql, self.quote());
+                write!(sql, ".").unwrap();
+                table.prepare(sql, self.quote());
+            }
+            TableRef::DatabaseSchemaTable(database, schema, table) => {
+                database.prepare(sql, self.quote());
+                write!(sql, ".").unwrap();
+                schema.prepare(sql, self.quote());
+                write!(sql, ".").unwrap();
+                table.prepare(sql, self.quote());
+            }
+            _ => panic!("Not supported"),
+        }
+    }
+
     /// Translate [`ColumnDef`] into SQL statement.
     fn prepare_column_def(&self, column_def: &ColumnDef, sql: &mut SqlWriter);
 
@@ -86,7 +112,7 @@ pub trait TableBuilder: IndexBuilder + ForeignKeyBuilder + QuotedBuilder {
             if !first {
                 write!(sql, ", ").unwrap();
             }
-            table.prepare(sql, self.quote());
+            self.prepare_table_ref(table, sql);
             false
         });
 
