@@ -41,7 +41,7 @@ use crate::{
 pub struct SelectStatement {
     pub(crate) distinct: Option<SelectDistinct>,
     pub(crate) selects: Vec<SelectExpr>,
-    pub(crate) from: Option<Box<TableRef>>,
+    pub(crate) from: Vec<TableRef>,
     pub(crate) join: Vec<JoinExpr>,
     pub(crate) r#where: ConditionHolder,
     pub(crate) groups: Vec<SimpleExpr>,
@@ -113,7 +113,7 @@ impl SelectStatement {
         Self {
             distinct: None,
             selects: Vec::new(),
-            from: None,
+            from: Vec::new(),
             join: Vec::new(),
             r#where: ConditionHolder::new(),
             groups: Vec::new(),
@@ -131,7 +131,7 @@ impl SelectStatement {
         Self {
             distinct: self.distinct.take(),
             selects: std::mem::take(&mut self.selects),
-            from: self.from.take(),
+            from: std::mem::take(&mut self.from),
             join: std::mem::take(&mut self.join),
             r#where: std::mem::replace(&mut self.r#where, ConditionHolder::new()),
             groups: std::mem::take(&mut self.groups),
@@ -570,6 +570,33 @@ impl SelectStatement {
     ///     r#"SELECT "font_size" FROM "database"."character"."glyph""#
     /// );
     /// ```
+    ///
+    /// If you specify `from` multiple times, the resulting query will have multiple from clauses.
+    /// You can perform an 'old-school' join this way.
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = sea_query::Query::select()
+    ///     .expr(Expr::asterisk())
+    ///     .from(Char::Table)
+    ///     .from(Font::Table)
+    ///     .and_where(Expr::tbl(Font::Table, Font::Id).equals(Char::Table, Char::FontId))
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT * FROM `character`, `font` WHERE `font`.`id` = `character`.`font_id`"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT * FROM "character", "font" WHERE "font"."id" = "character"."font_id""#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT * FROM "character", "font" WHERE "font"."id" = "character"."font_id""#
+    /// );
+    /// ```
     pub fn from<R>(&mut self, tbl_ref: R) -> &mut Self
     where
         R: IntoTableRef,
@@ -742,7 +769,7 @@ impl SelectStatement {
     }
 
     fn from_from(&mut self, select: TableRef) -> &mut Self {
-        self.from = Some(Box::new(select));
+        self.from.push(select);
         self
     }
 
