@@ -64,21 +64,21 @@ use crate::{
 /// assert_eq!(
 ///     table.to_string(SqliteQueryBuilder),
 ///     vec![
-///        r#"CREATE TABLE IF NOT EXISTS `character` ("#,
-///            r#"`id` integer NOT NULL PRIMARY KEY AUTOINCREMENT,"#,
-///            r#"`font_size` integer NOT NULL,"#,
-///            r#"`character` text NOT NULL,"#,
-///            r#"`size_w` integer NOT NULL,"#,
-///            r#"`size_h` integer NOT NULL,"#,
-///            r#"`font_id` integer DEFAULT NULL,"#,
-///            r#"FOREIGN KEY (`font_id`) REFERENCES `font` (`id`) ON DELETE CASCADE ON UPDATE CASCADE"#,
+///        r#"CREATE TABLE IF NOT EXISTS "character" ("#,
+///            r#""id" integer NOT NULL PRIMARY KEY AUTOINCREMENT,"#,
+///            r#""font_size" integer NOT NULL,"#,
+///            r#""character" text NOT NULL,"#,
+///            r#""size_w" integer NOT NULL,"#,
+///            r#""size_h" integer NOT NULL,"#,
+///            r#""font_id" integer DEFAULT NULL,"#,
+///            r#"FOREIGN KEY ("font_id") REFERENCES "font" ("id") ON DELETE CASCADE ON UPDATE CASCADE"#,
 ///        r#")"#,
 ///     ].join(" ")
 /// );
 /// ```
 #[derive(Debug, Clone)]
 pub struct TableCreateStatement {
-    pub(crate) table: Option<DynIden>,
+    pub(crate) table: Option<TableRef>,
     pub(crate) columns: Vec<ColumnDef>,
     pub(crate) options: Vec<TableOpt>,
     pub(crate) partitions: Vec<TablePartition>,
@@ -135,11 +135,11 @@ impl TableCreateStatement {
     }
 
     /// Set table name
-    pub fn table<T: 'static>(&mut self, table: T) -> &mut Self
+    pub fn table<T>(&mut self, table: T) -> &mut Self
     where
-        T: Iden,
+        T: IntoTableRef,
     {
-        self.table = Some(SeaRc::new(table));
+        self.table = Some(table.into_table_ref());
         self
     }
 
@@ -216,11 +216,11 @@ impl TableCreateStatement {
     /// assert_eq!(
     ///     statement.to_string(SqliteQueryBuilder),
     ///     vec![
-    ///         "CREATE TABLE `glyph` (",
-    ///         "`id` integer NOT NULL,",
-    ///         "`image` text NOT NULL,",
-    ///         "PRIMARY KEY (`id`, `image`)",
-    ///         ")",
+    ///         r#"CREATE TABLE "glyph" ("#,
+    ///         r#""id" integer NOT NULL,"#,
+    ///         r#""image" text NOT NULL,"#,
+    ///         r#"PRIMARY KEY ("id", "image")"#,
+    ///         r#")"#,
     ///     ]
     ///     .join(" ")
     /// );
@@ -267,8 +267,8 @@ impl TableCreateStatement {
         self
     }
 
-    pub fn get_table_name(&self) -> Option<String> {
-        self.table.as_ref().map(|table| table.to_string())
+    pub fn get_table_name(&self) -> Option<&TableRef> {
+        self.table.as_ref()
     }
 
     pub fn get_columns(&self) -> &Vec<ColumnDef> {
