@@ -899,6 +899,21 @@ fn select_53() {
     );
 }
 
+#[test]
+fn select_54() {
+    let statement = sea_query::Query::select()
+        .expr(Expr::asterisk())
+        .from(Char::Table)
+        .from(Font::Table)
+        .and_where(Expr::tbl(Font::Table, Font::Id).equals(Char::Table, Char::FontId))
+        .to_string(MysqlQueryBuilder);
+
+    assert_eq!(
+        statement,
+        r#"SELECT * FROM `character`, `font` WHERE `font`.`id` = `character`.`font_id`"#
+    );
+}
+
 #[test]
 #[allow(clippy::approx_constant)]
 fn insert_2() {
@@ -967,27 +982,6 @@ fn insert_5() {
     );
 }
 
-#[test]
-fn insert_6() {
-    assert_eq!(
-        Query::insert()
-            .into_table(Glyph::Table)
-            .to_string(MysqlQueryBuilder),
-        "INSERT INTO `glyph` VALUES (DEFAULT)"
-    );
-}
-
-#[test]
-fn insert_7() {
-    assert_eq!(
-        Query::insert()
-            .into_table(Glyph::Table)
-            .returning_col(Glyph::Id)
-            .to_string(MysqlQueryBuilder),
-        "INSERT INTO `glyph` VALUES (DEFAULT)"
-    );
-}
-
 #[test]
 fn insert_from_select() {
     assert_eq!(
