@@ -877,6 +877,21 @@ fn select_53() {
     );
 }
 
+#[test]
+fn select_54() {
+    let statement = sea_query::Query::select()
+        .expr(Expr::asterisk())
+        .from(Char::Table)
+        .from(Font::Table)
+        .and_where(Expr::tbl(Font::Table, Font::Id).equals(Char::Table, Char::FontId))
+        .to_string(PostgresQueryBuilder);
+
+    assert_eq!(
+        statement,
+        r#"SELECT * FROM "character", "font" WHERE "font"."id" = "character"."font_id""#
+    );
+}
+
 #[test]
 #[allow(clippy::approx_constant)]
 fn insert_2() {
@@ -936,6 +951,35 @@ fn insert_5() {
     );
 }
 
+#[test]
+fn insert_from_select() {
+    assert_eq!(
+        Query::insert()
+            .into_table(Glyph::Table)
+            .columns(vec![Glyph::Aspect, Glyph::Image])
+            .select_from(
+                Query::select()
+                    .column(Glyph::Aspect)
+                    .column(Glyph::Image)
+                    .from(Glyph::Table)
+                    .conditions(
+                        true,
+                        |x| {
+                            x.and_where(Expr::col(Glyph::Image).like("%"));
+                        },
+                        |x| {
+                            x.and_where(Expr::col(Glyph::Id).eq(6));
+                        },
+                    )
+                    .to_owned()
+            )
+            .unwrap()
+            .to_owned()
+            .to_string(PostgresQueryBuilder),
+        r#"INSERT INTO "glyph" ("aspect", "image") SELECT "aspect", "image" FROM "glyph" WHERE "image" LIKE '%'"#
+    );
+}
+
 #[test]
 fn insert_6() -> sea_query::error::Result<()> {
     let select = SelectStatement::new()
@@ -970,56 +1014,6 @@ fn insert_6() -> sea_query::error::Result<()> {
     Ok(())
 }
 
-#[test]
-fn insert_7() {
-    assert_eq!(
-        Query::insert()
-            .into_table(Glyph::Table)
-            .to_string(PostgresQueryBuilder),
-        "INSERT INTO \"glyph\" DEFAULT VALUES"
-    );
-}
-
-#[test]
-fn insert_8() {
-    assert_eq!(
-        Query::insert()
-            .into_table(Glyph::Table)
-            .returning_col(Glyph::Id)
-            .to_string(PostgresQueryBuilder),
-        "INSERT INTO \"glyph\" DEFAULT VALUES RETURNING \"id\""
-    );
-}
-
-#[test]
-fn insert_from_select() {
-    assert_eq!(
-        Query::insert()
-            .into_table(Glyph::Table)
-            .columns(vec![Glyph::Aspect, Glyph::Image])
-            .select_from(
-                Query::select()
-                    .column(Glyph::Aspect)
-                    .column(Glyph::Image)
-                    .from(Glyph::Table)
-                    .conditions(
-                        true,
-                        |x| {
-                            x.and_where(Expr::col(Glyph::Image).like("%"));
-                        },
-                        |x| {
-                            x.and_where(Expr::col(Glyph::Id).eq(6));
-                        },
-                    )
-                    .to_owned()
-            )
-            .unwrap()
-            .to_owned()
-            .to_string(PostgresQueryBuilder),
-        r#"INSERT INTO "glyph" ("aspect", "image") SELECT "aspect", "image" FROM "glyph" WHERE "image" LIKE '%'"#
-    );
-}
-
 #[test]
 fn update_1() {
     assert_eq!(
