@@ -877,6 +877,21 @@ fn select_53() {
     );
 }
 
+#[test]
+fn select_54() {
+    let statement = sea_query::Query::select()
+        .expr(Expr::asterisk())
+        .from(Char::Table)
+        .from(Font::Table)
+        .and_where(Expr::tbl(Font::Table, Font::Id).equals(Char::Table, Char::FontId))
+        .to_string(SqliteQueryBuilder);
+
+    assert_eq!(
+        statement,
+        r#"SELECT * FROM "character", "font" WHERE "font"."id" = "character"."font_id""#
+    );
+}
+
 #[test]
 #[allow(clippy::approx_constant)]
 fn insert_2() {
@@ -965,27 +980,6 @@ fn insert_5() {
     );
 }
 
-#[test]
-fn insert_6() {
-    assert_eq!(
-        Query::insert()
-            .into_table(Glyph::Table)
-            .to_string(SqliteQueryBuilder),
-        r#"INSERT INTO "glyph" DEFAULT VALUES"#
-    );
-}
-
-#[test]
-fn insert_7() {
-    assert_eq!(
-        Query::insert()
-            .into_table(Glyph::Table)
-            .returning_col(Glyph::Id)
-            .to_string(SqliteQueryBuilder),
-        r#"INSERT INTO "glyph" DEFAULT VALUES RETURNING "id""#
-    );
-}
-
 #[test]
 fn update_1() {
     assert_eq!(
